import { feature } from "topojson";
import {select,
        json,
        geoPath, 
        geoMercator,
        zoom,
        event} from "d3";


const projection = geoMercator().scale(4000).translate([-5850, 2000])
const pathGenerator = geoPath().projection(projection);
const HeaderText = "Bangladesh Administrative Infos";

// Creating svg object and setting its characteristics 
const svg = d3.select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');
const g= svg.append('g');
svg.style('background-color',"white");
svg.append('text').attr('y',40).attr('x',300).text(HeaderText);
svg.append('text').attr('y',height-150).attr('x',width-280).text('').attr('class',"tips");
svg.call(zoom().on('zoom',()=>{
	console.log("Zooming..");
  g.attr('transform',event.transform);
}));


// Parsing Data
Promise.all([
  json("countryData.json"),
	json("https://gist.githubusercontent.com/Platoch/a1b2d8bfc60df35104b6c16712163bc3/raw/"
       + "a95b9b01794ca87611f4e3c2177632c2403f1b46/Bangladesh.json")
]).then(([countryData,topoJsonData])=> {
  console.log(topoJsonData);
    // Get Sales information on hover
      const getSalesInformation =(d)=> {
        const districtName = d.properties.name;
        let selectedDistrict = countryData.filter(obj => {
            return obj.name === districtName;
        })
// Infos to display when the mose hovers on a division
        let outputString = `Capital: ${selectedDistrict[0].name}
       										 \nPopulation: ${selectedDistrict[0].population} 
        										\nArea in Km2: ${selectedDistrict[0].area} 
        										\nDensity of population: ${selectedDistrict[0].density}`;  
        return outputString;
    }
// Parsing feature from Data
    const subdistrict = feature(topoJsonData, topoJsonData.objects["map"]);  

// Construct map path from feature data( subdistrict);
    const dist = g.selectAll('path').data(subdistrict.features).enter().append('path')
            .attr('class', 'district')
            .attr('d', pathGenerator);
        dist.append('title')
            .text((d)=>getSalesInformation(d));
});

